@@ -37,15 +37,6 @@
 #include "common.h"
 #include "backend.h"
 #include "moves.h"
-#include "gettext.h"
-
-#ifdef ENABLE_NLS
-# define  _(s) gettext (s)
-# define N_(s) gettext_noop (s)
-#else
-# define  _(s) (s)
-# define N_(s)  s
-#endif
 
 #ifdef _MSC_VER
   typedef unsigned __int64 uint64;
@@ -53,6 +44,7 @@
   typedef unsigned long long int uint64;
 #endif
 
+
 #ifdef _MSC_VER
 #  define U64(u) (u##ui64)
 #else
@@ -282,8 +274,7 @@ uint64 *RandomEnPassant =Random64+772;
 uint64 *RandomTurn      =Random64+780;
 
 
-uint64
-hash (int moveNr)
+uint64 hash(int moveNr)
 {
     int r, f, p_enc, squareNr, pieceGroup;
     uint64 key=0, holdingsKey=0, Zobrist;
@@ -379,8 +370,7 @@ hash (int moveNr)
 
 #define MOVE_BUF 100
 
-int
-int_from_file (FILE *f, int l, uint64 *r)
+int int_from_file(FILE *f, int l, uint64 *r)
 {
     int i,c;
     for(i=0;i<l;i++){
@@ -393,8 +383,7 @@ int_from_file (FILE *f, int l, uint64 *r)
     return 0;
 }
 
-int
-entry_from_file (FILE *f, entry_t *entry)
+int entry_from_file(FILE *f, entry_t *entry)
 {
     int ret;
     uint64 r;
@@ -416,8 +405,7 @@ entry_from_file (FILE *f, entry_t *entry)
     return 0;
 }
 
-int
-find_key (FILE *f, uint64 key, entry_t *entry)
+int find_key(FILE *f, uint64 key, entry_t *entry)
 {
     int first, last, middle;
     entry_t first_entry=entry_none, last_entry,middle_entry;
@@ -447,8 +435,7 @@ find_key (FILE *f, uint64 key, entry_t *entry)
     }
 }
 
-void
-move_to_string (char move_s[6], uint16 move)
+void move_to_string(char move_s[6], uint16 move)
 {
     int f,fr,ff,t,tr,tf,p;
     int width = BOARD_RGHT - BOARD_LEFT, size; // allow for alternative board formats
@@ -496,8 +483,7 @@ move_to_string (char move_s[6], uint16 move)
     }
 }
 
-int
-GetBookMoves (int moveNr, char *book, entry_t entries[])
+int GetBookMoves(int moveNr, char *book, entry_t entries[])
 {   // retrieve all entries for given position from book in 'entries', return number.
     static FILE *f = NULL;
     static char curBook[MSG_SIZ];
@@ -515,7 +501,7 @@ GetBookMoves (int moveNr, char *book, entry_t entries[])
 	f = fopen(book,"rb");
     }
     if(!f){
-        DisplayError(_("Polyglot book not valid"), 0);
+	DisplayError("Polyglot book not valid", 0);
 	appData.usePolyglotBook = FALSE;
 	return -1;
     }
@@ -544,9 +530,8 @@ GetBookMoves (int moveNr, char *book, entry_t entries[])
     return count;
 }
 
-char *
-ProbeBook (int moveNr, char *book)
-{
+char *ProbeBook(int moveNr, char *book)
+{   // 
     entry_t entries[MOVE_BUF];
     int count;
     int i, j;
@@ -576,7 +561,7 @@ ProbeBook (int moveNr, char *book)
         total_weight += entries[i].weight;
 	if(total_weight > j) break;
     }
-    if(i >= count) DisplayFatalError(_("Book Fault"), 0, 1); // safety catch, cannot happen
+    if(i >= count) DisplayFatalError("Book Fault", 0, 1); // safety catch, cannot happen
     move_to_string(move_s, entries[i].move);
     if(appData.debugMode) fprintf(debugFP, "book move field = %d\n", entries[i].move);
 
@@ -586,8 +571,7 @@ ProbeBook (int moveNr, char *book)
 extern char yy_textstr[];
 entry_t lastEntries[MOVE_BUF];
 
-char *
-MovesToText (int count, entry_t *entries)
+char *MovesToText(int count, entry_t *entries)
 {
 	int i, totalWeight = 0;
 	char algMove[6];
@@ -607,8 +591,7 @@ MovesToText (int count, entry_t *entries)
 	return p;
 }
 
-int
-TextToMoves (char *text, int moveNum, entry_t *entries)
+int TextToMoves(char *text, int moveNum, entry_t *entries)
 {
 	int i, w, count=0;
       uint64 hashKey = hash(moveNum);
@@ -647,8 +630,7 @@ TextToMoves (char *text, int moveNum, entry_t *entries)
 Boolean bookUp;
 int currentCount;
 
-Boolean
-DisplayBook (int moveNr)
+Boolean DisplayBook(int moveNr)
 {
     entry_t entries[MOVE_BUF];
     int count;
@@ -662,22 +644,19 @@ DisplayBook (int moveNr)
     return TRUE;
 }
 
-void
-EditBookEvent ()
+void EditBookEvent()
 {
       bookUp = TRUE;
 	bookUp = DisplayBook(currentMove);
 }
 
-void
-int_to_file (FILE *f, int l, uint64 r)
+void int_to_file(FILE *f, int l, uint64 r)
 {
     int i;
     for(i=l-1;i>=0;i--) fputc(r>>8*i & 255, f);
 }
 
-void
-entry_to_file (FILE *f, entry_t *entry)
+void entry_to_file(FILE *f, entry_t *entry)
 {
     int_to_file(f,8,entry->key);
     int_to_file(f,2,entry->move);
@@ -688,8 +667,7 @@ entry_to_file (FILE *f, entry_t *entry)
 
 char buf1[4096], buf2[4096];
 
-void
-SaveToBook (char *text)
+void SaveToBook(char *text)
 {
     entry_t entries[MOVE_BUF], entry;
     int count = TextToMoves(text, currentMove, entries);
@@ -697,10 +675,10 @@ SaveToBook (char *text)
     FILE *f;
     if(!count && !currentCount) return;
     f=fopen(appData.polyglotBook, "rb+");
-    if(!f){	DisplayError(_("Polyglot book not valid"), 0); return; }
+    if(!f){	DisplayError("Polyglot book not valid", 0); return; }
     offset=find_key(f, entries[0].key, &entry);
     if(entries[0].key != entry.key && currentCount) {
-          DisplayError(_("Hash keys are different"), 0);
+	  DisplayError("Hash keys are different", 0);
 	  fclose(f);
 	  return;
     }
