@@ -500,6 +500,7 @@
 #define OPT_VariantMakruk               1529
 #define OPT_VariantSChess               1530
 #define OPT_VariantSpartan              1531
+#define OPT_VariantGrand                1534
 #define IDC_Files                       1550
 #define IDC_Ranks                       1551
 #define IDC_Holdings                    1552
@@ -538,6 +539,8 @@
 #define OPT_MESS                        1818
 #define IDM_Engine1Options		1890
 #define IDM_Engine2Options		1891
+#define IDM_EditBook			1892
+#define IDM_Tourney			1894
 #define IDC_STATIC                      -1
 // static strings that were made dynamic to allow run-time translation
 #define IDC_Babble			1900
@@ -595,6 +598,33 @@
 #define IDC_Variation			1952
 #define IDC_DefGames			1953
 #define GPB_Variant			1954
+#define OPT_MessageFont7                1955
+#define OPT_SampleGameListFont          1956
+#define OPT_ChooseGameListFont          1957
+#define OPT_elo1                        1958
+#define OPT_elo2                        1959
+#define OPT_date                        1960
+#define OPT_elo1t                       1961
+#define OPT_elo2t                       1962
+#define OPT_datet                       1963
+#define OPT_thresholds                  1964
+#define OPT_Exact                       1965
+#define OPT_Subset                      1966
+#define OPT_Struct                      1967
+#define OPT_Material                    1968
+#define OPT_Range                       1969
+#define OPT_Difference                  1970
+#define OPT_Stretch                     1971
+#define OPT_Stretcht                    1972
+#define OPT_Reversed                    1973
+#define OPT_SearchMode                  1974
+#define OPT_Mirror                      1975
+#define OPT_Bitmaps                     1976
+#define OPT_PieceFont                   1977
+#define OPT_MessageFont8                1978
+#define OPT_SamplePieceFont             1979
+#define OPT_ChoosePieceFont             1980
+#define OPT_GameListFind                1981
 
 
 // Next default values for new objects
