@@ -1,7 +1,7 @@
 /*
  * xgamelist.c -- Game list window, part of X front end for XBoard
  *
- * Copyright 1995, 2009, 2010, 2011, 2012 Free Software Foundation, Inc.
+ * Copyright 1995, 2009, 2010, 2011 Free Software Foundation, Inc.
  * ------------------------------------------------------------------------
  *
  * GNU XBoard is free software: you can redistribute it and/or modify
@@ -125,7 +125,10 @@ typedef struct {
 static GameListClosure *glc = NULL;
 
 Widget
-GameListCreate (char *name, XtCallbackProc callback, XtPointer client_data)
+GameListCreate(name, callback, client_data)
+     char *name;
+     XtCallbackProc callback;
+     XtPointer client_data;
 {
     Arg args[16];
     Widget shell, form, viewport, listwidg, layout, label;
@@ -327,14 +330,16 @@ extern int soughtCounts[];
 extern Board soughtBoard;
 
 static int
-GameListPrepare (int byPos)
+GameListPrepare(int byPos)
 {   // [HGM] filter: put in separate routine, to make callable from call-back
     int nstrings;
     ListGame *lg;
     char **st, *line;
-    TimeMark t, t2;
+struct {
+    long sec;  /* Assuming this is >= 32 bits */
+    int ms;    /* Assuming this is >= 16 bits */
+} t,t2; GetTimeMark(&t);
 
-    GetTimeMark(&t);
     if(st = glc->strings) while(*st) free(*st++);
     nstrings = ((ListGame *) gameList.tailPred)->number;
     glc->strings = (char **) malloc((nstrings + 1) * sizeof(char *));
@@ -360,7 +365,7 @@ GameListPrepare (int byPos)
 	lg->position = pos;
 	lg = (ListGame *) lg->node.succ;
      }
-GetTimeMark(&t2);printf("GameListPrepare %ld msec\n", SubtractTimeMarks(&t2,&t));
+GetTimeMark(&t2);printf("GameListPrepare %d msec\n", SubtractTimeMarks(&t2,&t));
      DisplayTitle("XBoard");
     *st = NULL;
     return listLength;
@@ -370,7 +375,7 @@ static char *list[1003];
 int listEnd;
 
 static void
-GameListReplace (int page)
+GameListReplace(int page)
 {
   // filter: put in separate routine, to make callable from call-back
   Widget listwidg;
@@ -389,13 +394,15 @@ GameListReplace (int page)
   XawListChange(listwidg, list, 0, 0, True);
   XtSetValues(listwidg, &arg, 1);
   XawListHighlight(listwidg, 0);
-  snprintf(buf, MSG_SIZ, _("%s - %d/%d games (%d-%d-%d)"), glc->filename, listLength, ((ListGame *) gameList.tailPred)->number, wins, losses, draws);
+  snprintf(buf, MSG_SIZ, "%s- %d/%d games (%d-%d-%d)", glc->filename, listLength, ((ListGame *) gameList.tailPred)->number, wins, losses, draws);
   XtSetArg(arg, XtNtitle, buf);
   XtSetValues(glc->shell, &arg, 1);
 }
 
 void
-GameListCallback (Widget w, XtPointer client_data, XtPointer call_data)
+GameListCallback(w, client_data, call_data)
+     Widget w;
+     XtPointer client_data, call_data;
 {
     String name;
     Arg args[16];
@@ -463,7 +470,9 @@ GameListCallback (Widget w, XtPointer client_data, XtPointer call_data)
 }
 
 void
-GameListPopUp (FILE *fp, char *filename)
+GameListPopUp(fp, filename)
+     FILE *fp;
+     char *filename;
 {
     Arg args[16];
     int j;
@@ -472,8 +481,6 @@ GameListPopUp (FILE *fp, char *filename)
     if (glc == NULL) {
 	glc = (GameListClosure *) calloc(1, sizeof(GameListClosure));
 	glc->x = glc->y = -1;
-	glc->filename = NULL;
-	glc->shell = NULL;
     }
 
     GameListPrepare(False); // [HGM] filter: code put in separate routine
@@ -483,6 +490,7 @@ GameListPopUp (FILE *fp, char *filename)
     if (glc->filename != NULL) free(glc->filename);
     glc->filename = StrSave(filename);
 
+
     if (glc->shell == NULL) {
 	glc->shell = GameListCreate(filename, GameListCallback, glc);
     } else {
@@ -503,7 +511,7 @@ GameListPopUp (FILE *fp, char *filename)
 }
 
 void
-GameListDestroy ()
+GameListDestroy()
 {
     if (glc == NULL) return;
     GameListPopDown();
@@ -520,7 +528,11 @@ GameListDestroy ()
 }
 
 void
-ShowGameListProc (Widget w, XEvent *event, String *prms, Cardinal *nprms)
+ShowGameListProc(w, event, prms, nprms)
+     Widget w;
+     XEvent *event;
+     String *prms;
+     Cardinal *nprms;
 {
     Arg args[16];
     int j;
@@ -543,7 +555,11 @@ ShowGameListProc (Widget w, XEvent *event, String *prms, Cardinal *nprms)
 }
 
 void
-LoadSelectedProc (Widget w, XEvent *event, String *prms, Cardinal *nprms)
+LoadSelectedProc(w, event, prms, nprms)
+     Widget w;
+     XEvent *event;
+     String *prms;
+     Cardinal *nprms;
 {
     Widget listwidg;
     XawListReturnStruct *rs;
@@ -587,7 +603,11 @@ LoadSelectedProc (Widget w, XEvent *event, String *prms, Cardinal *nprms)
 }
 
 void
-SetFilterProc (Widget w, XEvent *event, String *prms, Cardinal *nprms)
+SetFilterProc(w, event, prms, nprms)
+     Widget w;
+     XEvent *event;
+     String *prms;
+     Cardinal *nprms;
 {
 	Arg args[16];
         String name;
@@ -606,7 +626,7 @@ SetFilterProc (Widget w, XEvent *event, String *prms, Cardinal *nprms)
 }
 
 void
-GameListPopDown ()
+GameListPopDown()
 {
     Arg args[16];
     int j;
@@ -632,7 +652,8 @@ GameListPopDown ()
 }
 
 void
-GameListHighlight (int index)
+GameListHighlight(index)
+     int index;
 {
     Widget listwidg;
     int i=0; char **st;
@@ -644,19 +665,18 @@ GameListHighlight (int index)
 }
 
 Boolean
-GameListIsUp ()
+GameListIsUp()
 {
     return glc && glc->up;
 }
 
-int
-SaveGameListAsText (FILE *f)
+int SaveGameListAsText(FILE *f)
 {
     ListGame * lg = (ListGame *) gameList.head;
     int nItem;
 
     if( !glc || ((ListGame *) gameList.tailPred)->number <= 0 ) {
-      DisplayError(_("Game list not loaded or empty"), 0);
+        DisplayError("Game list not loaded or empty", 0);
         return False;
     }
 
@@ -686,36 +706,32 @@ Widget gameListOptShell, listwidg;
 char *strings[20];
 int stringPtr;
 
-void
-GLT_ClearList ()
+void GLT_ClearList()
 {
     strings[0] = NULL;
     stringPtr = 0;
 }
 
-void
-GLT_AddToList (char *name)
+void GLT_AddToList(char *name)
 {
     strings[stringPtr++] = name;
     strings[stringPtr] = NULL;
 }
 
-Boolean
-GLT_GetFromList (int index, char *name)
+Boolean GLT_GetFromList(int index, char *name)
 {
   safeStrCpy(name, strings[index], MSG_SIZ);
   return TRUE;
 }
 
-void
-GLT_DeSelectList ()
+void GLT_DeSelectList()
 {
     XawListChange(listwidg, strings, 0, 0, True);
     XawListHighlight(listwidg, 0);
 }
 
 void
-GameListOptionsPopDown ()
+GameListOptionsPopDown()
 {
   if (gameListOptShell == NULL) return;
 
@@ -726,7 +742,9 @@ GameListOptionsPopDown ()
 }
 
 void
-GameListOptionsCallback (Widget w, XtPointer client_data, XtPointer call_data)
+GameListOptionsCallback(w, client_data, call_data)
+     Widget w;
+     XtPointer client_data, call_data;
 {
     String name;
     Arg args[16];
@@ -777,7 +795,7 @@ GameListOptionsCallback (Widget w, XtPointer client_data, XtPointer call_data)
 }
 
 Widget
-GameListOptionsCreate ()
+GameListOptionsCreate()
 {
     Arg args[16];
     Widget shell, form, viewport, layout;
@@ -794,7 +812,7 @@ GameListOptionsCreate ()
     XtSetArg(args[j], XtNresizable, True);  j++;
     XtSetArg(args[j], XtNallowShellResize, True);  j++;
     shell = gameListOptShell =
-      XtCreatePopupShell(_("Game-list options"), transientShellWidgetClass,
+      XtCreatePopupShell("Game-list options", transientShellWidgetClass,
 			 shellWidget, args, j);
     layout =
       XtCreateManagedWidget(layoutName, formWidgetClass, shell,
@@ -878,7 +896,7 @@ GameListOptionsCreate ()
 }
 
 void
-GameListOptionsPopUp (Widget w, XEvent *event, String *prms, Cardinal *nprms)
+GameListOptionsPopUp(Widget w, XEvent *event, String *prms, Cardinal *nprms)
 {
   if (gameListOptShell == NULL)
     gameListOptShell = GameListOptionsCreate();
